# Copyright 2023-2024 Luminary Cloud, Inc. All Rights Reserved.
from enum import IntEnum
from .._proto.api.v0.luminarycloud.simulation import simulation_pb2 as simulationpb


class QuantityType(IntEnum):
    """
    Represents a quantity type.

    Attributes
    ----------
    DENSITY
    DISK_THRUST
    DISK_TORQUE
    DOWNFORCE
    DOWNFORCE_COEFFICIENT
    DRAG
    DRAG_COEFFICIENT
    ENERGY_FLUX
    FRICTION_FORCE
    FRICTION_FORCE_COEFFICIENT
    LIFT
    LIFT_COEFFICIENT
    MACH
    PITCHING_MOMENT
    PITCHING_MOMENT_COEFFICIENT
    PRESSURE
    PRESSURE_DRAG
    PRESSURE_DRAG_COEFFICIENT
    PRESSURE_FORCE
    PRESSURE_FORCE_COEFFICIENT
    ROLLING_MOMENT
    ROLLING_MOMENT_COEFFICIENT
    SIDEFORCE
    SIDEFORCE_COEFFICIENT
    TEMPERATURE
    TOTAL_FORCE
    TOTAL_FORCE_COEFFICIENT
    TOTAL_MOMENT
    TOTAL_MOMENT_COEFFICIENT
    TOTAL_PRESSURE
    TOTAL_TEMPERATURE
    VELOCITY_MAGNITUDE
    VELOCITY_X
    VELOCITY_Y
    VELOCITY_Z
    VISCOUS_DRAG
    VISCOUS_DRAG_COEFFICIENT
    Y_PLUS
    YAWING_MOMENT
    YAWING_MOMENT_COEFFICIENT
    """

    UNSPECIFIED = simulationpb.QUANTITY_TYPE_UNSPECIFIED

    # Force quantity types
    DISK_THRUST = simulationpb.QUANTITY_TYPE_DISK_THRUST
    DISK_TORQUE = simulationpb.QUANTITY_TYPE_DISK_TORQUE
    DOWNFORCE = simulationpb.QUANTITY_TYPE_DOWNFORCE
    DOWNFORCE_COEFFICIENT = simulationpb.QUANTITY_TYPE_DOWNFORCE_COEFFICIENT
    DRAG = simulationpb.QUANTITY_TYPE_DRAG
    DRAG_COEFFICIENT = simulationpb.QUANTITY_TYPE_DRAG_COEFFICIENT
    FRICTION_FORCE = simulationpb.QUANTITY_TYPE_FRICTION_FORCE
    FRICTION_FORCE_COEFFICIENT = simulationpb.QUANTITY_TYPE_FRICTION_FORCE_COEFFICIENT
    LIFT = simulationpb.QUANTITY_TYPE_LIFT
    LIFT_COEFFICIENT = simulationpb.QUANTITY_TYPE_LIFT_COEFFICIENT
    PITCHING_MOMENT = simulationpb.QUANTITY_TYPE_PITCHING_MOMENT
    PITCHING_MOMENT_COEFFICIENT = simulationpb.QUANTITY_TYPE_PITCHING_MOMENT_COEFFICIENT
    PRESSURE_FORCE = simulationpb.QUANTITY_TYPE_PRESSURE_FORCE
    PRESSURE_FORCE_COEFFICIENT = simulationpb.QUANTITY_TYPE_PRESSURE_FORCE_COEFFICIENT
    ROLLING_MOMENT = simulationpb.QUANTITY_TYPE_ROLLING_MOMENT
    ROLLING_MOMENT_COEFFICIENT = simulationpb.QUANTITY_TYPE_ROLLING_MOMENT_COEFFICIENT
    SIDEFORCE = simulationpb.QUANTITY_TYPE_SIDEFORCE
    SIDEFORCE_COEFFICIENT = simulationpb.QUANTITY_TYPE_SIDEFORCE_COEFFICIENT
    TOTAL_FORCE = simulationpb.QUANTITY_TYPE_TOTAL_FORCE
    TOTAL_FORCE_COEFFICIENT = simulationpb.QUANTITY_TYPE_TOTAL_FORCE_COEFFICIENT
    TOTAL_MOMENT = simulationpb.QUANTITY_TYPE_TOTAL_MOMENT
    TOTAL_MOMENT_COEFFICIENT = simulationpb.QUANTITY_TYPE_TOTAL_MOMENT_COEFFICIENT
    YAWING_MOMENT = simulationpb.QUANTITY_TYPE_YAWING_MOMENT
    YAWING_MOMENT_COEFFICIENT = simulationpb.QUANTITY_TYPE_YAWING_MOMENT_COEFFICIENT
    PRESSURE_DRAG = simulationpb.QUANTITY_TYPE_PRESSURE_DRAG
    PRESSURE_DRAG_COEFFICIENT = simulationpb.QUANTITY_TYPE_PRESSURE_DRAG_COEFFICIENT
    VISCOUS_DRAG = simulationpb.QUANTITY_TYPE_VISCOUS_DRAG
    VISCOUS_DRAG_COEFFICIENT = simulationpb.QUANTITY_TYPE_VISCOUS_DRAG_COEFFICIENT

    # Average quantity types
    DENSITY = simulationpb.QUANTITY_TYPE_DENSITY
    ENERGY_FLUX = simulationpb.QUANTITY_TYPE_ENERGY_FLUX
    MACH = simulationpb.QUANTITY_TYPE_MACH
    PRESSURE = simulationpb.QUANTITY_TYPE_PRESSURE
    TEMPERATURE = simulationpb.QUANTITY_TYPE_TEMPERATURE
    TOTAL_PRESSURE = simulationpb.QUANTITY_TYPE_TOTAL_PRESSURE
    TOTAL_TEMPERATURE = simulationpb.QUANTITY_TYPE_TOTAL_TEMPERATURE
    VELOCITY_MAGNITUDE = simulationpb.QUANTITY_TYPE_VELOCITY_MAGNITUDE
    VELOCITY_X = simulationpb.QUANTITY_TYPE_VELOCITY_X
    VELOCITY_Y = simulationpb.QUANTITY_TYPE_VELOCITY_Y
    VELOCITY_Z = simulationpb.QUANTITY_TYPE_VELOCITY_Z
    Y_PLUS = simulationpb.QUANTITY_TYPE_Y_PLUS
